(namespaced m ns)Inputs: [m :- (s/pred map?) ns :- s/Str] Returns: (s/pred map?)
Recursively namespace map keys with the given namespace string
Inputs: [m :- (s/pred map?) ns :- s/Str] Returns: (s/pred map?) Recursively namespace map keys with the given namespace string
(un-namespaced schema)Inputs: [schema :- (s/pred map?)] Returns: (s/pred map?)
Recursively un-namespace map keys
Inputs: [schema :- (s/pred map?)] Returns: (s/pred map?) Recursively un-namespace map keys
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |